"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const actions_core_1 = require("@segment/actions-core");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const init_script_1 = require("./init-script");
const sendTrackEvent_1 = tslib_1.__importDefault(require("./sendTrackEvent"));
const sendUserData_1 = tslib_1.__importDefault(require("./sendUserData"));
const ENDPOINT_UNDERCITY = 'https://undercity.usejimo.com/jimo-invader.js';
exports.destination = {
    name: 'Jimo (Actions)',
    slug: 'actions-jimo',
    mode: 'device',
    description: 'Load Jimo SDK and send user profile data to Jimo',
    settings: {
        projectId: {
            description: 'Id of the Jimo project. You can find the Project Id here: https://i.usejimo.com/settings/install/portal',
            label: 'Id',
            type: 'string',
            required: true
        },
        refetchExperiencesOnTraitsUpdate: {
            description: "Enable this option if you'd like Jimo to refetch experiences supposed to be shown to the user after user traits get updated. This is useful when if you have experiences that use segment based on Segment traits.",
            label: 'Refetch experiences after traits changes',
            type: 'boolean',
            default: false
        },
        manualInit: {
            description: 'If true, Jimo SDK will be initialized only after a Segment event containing a userID has been triggered. This prevents from having anonymous profile created in Jimo.',
            label: 'Initialize only for identified users',
            type: 'boolean',
            default: false
        }
    },
    presets: [
        {
            name: 'Send User Data',
            subscribe: 'type = "identify"',
            partnerAction: 'sendUserData',
            mapping: (0, actions_core_1.defaultValues)(sendUserData_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Send Track Event',
            subscribe: 'type = "track"',
            partnerAction: 'sendTrackEvent',
            mapping: (0, actions_core_1.defaultValues)(sendTrackEvent_1.default.fields),
            type: 'automatic'
        }
    ],
    initialize: async ({ settings }, deps) => {
        (0, init_script_1.initScript)(settings);
        await deps.loadScript(`${ENDPOINT_UNDERCITY}`);
        return window.segmentJimo;
    },
    actions: {
        sendUserData: sendUserData_1.default,
        sendTrackEvent: sendTrackEvent_1.default
    }
};
exports.default = (0, shim_1.browserDestination)(exports.destination);
//# sourceMappingURL=index.js.map